/****************************************************************************
** Meta object code from reading C++ file 'query.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kxmlrpcclient-5.43.0/src/query.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'query.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KXmlRpc__Query_t {
    QByteArrayData data[21];
    char stringdata0[174];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KXmlRpc__Query_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KXmlRpc__Query_t qt_meta_stringdata_KXmlRpc__Query = {
    {
QT_MOC_LITERAL(0, 0, 14), // "KXmlRpc::Query"
QT_MOC_LITERAL(1, 15, 7), // "message"
QT_MOC_LITERAL(2, 23, 0), // ""
QT_MOC_LITERAL(3, 24, 6), // "result"
QT_MOC_LITERAL(4, 31, 2), // "id"
QT_MOC_LITERAL(5, 34, 5), // "fault"
QT_MOC_LITERAL(6, 40, 7), // "errCode"
QT_MOC_LITERAL(7, 48, 9), // "errString"
QT_MOC_LITERAL(8, 58, 8), // "finished"
QT_MOC_LITERAL(9, 67, 6), // "Query*"
QT_MOC_LITERAL(10, 74, 5), // "query"
QT_MOC_LITERAL(11, 80, 4), // "call"
QT_MOC_LITERAL(12, 85, 6), // "server"
QT_MOC_LITERAL(13, 92, 6), // "method"
QT_MOC_LITERAL(14, 99, 4), // "args"
QT_MOC_LITERAL(15, 104, 21), // "QMap<QString,QString>"
QT_MOC_LITERAL(16, 126, 11), // "jobMetaData"
QT_MOC_LITERAL(17, 138, 8), // "slotData"
QT_MOC_LITERAL(18, 147, 9), // "KIO::Job*"
QT_MOC_LITERAL(19, 157, 10), // "slotResult"
QT_MOC_LITERAL(20, 168, 5) // "KJob*"

    },
    "KXmlRpc::Query\0message\0\0result\0id\0"
    "fault\0errCode\0errString\0finished\0"
    "Query*\0query\0call\0server\0method\0args\0"
    "QMap<QString,QString>\0jobMetaData\0"
    "slotData\0KIO::Job*\0slotResult\0KJob*"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KXmlRpc__Query[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   44,    2, 0x06 /* Public */,
       5,    3,   49,    2, 0x06 /* Public */,
       8,    1,   56,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      11,    4,   59,    2, 0x0a /* Public */,
      17,    2,   68,    2, 0x08 /* Private */,
      19,    1,   73,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QVariantList, QMetaType::QVariant,    3,    4,
    QMetaType::Void, QMetaType::Int, QMetaType::QString, QMetaType::QVariant,    6,    7,    4,
    QMetaType::Void, 0x80000000 | 9,   10,

 // slots: parameters
    QMetaType::Void, QMetaType::QUrl, QMetaType::QString, QMetaType::QVariantList, 0x80000000 | 15,   12,   13,   14,   16,
    QMetaType::Void, 0x80000000 | 18, QMetaType::QByteArray,    2,    2,
    QMetaType::Void, 0x80000000 | 20,    2,

       0        // eod
};

void KXmlRpc::Query::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Query *_t = static_cast<Query *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->message((*reinterpret_cast< const QList<QVariant>(*)>(_a[1])),(*reinterpret_cast< const QVariant(*)>(_a[2]))); break;
        case 1: _t->fault((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QVariant(*)>(_a[3]))); break;
        case 2: _t->finished((*reinterpret_cast< Query*(*)>(_a[1]))); break;
        case 3: _t->call((*reinterpret_cast< const QUrl(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QList<QVariant>(*)>(_a[3])),(*reinterpret_cast< const QMap<QString,QString>(*)>(_a[4]))); break;
        case 4: _t->d->slotData((*reinterpret_cast< KIO::Job*(*)>(_a[1])),(*reinterpret_cast< const QByteArray(*)>(_a[2]))); break;
        case 5: _t->d->slotResult((*reinterpret_cast< KJob*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Query* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (Query::*_t)(const QList<QVariant> & , const QVariant & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Query::message)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (Query::*_t)(int , const QString & , const QVariant & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Query::fault)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (Query::*_t)(Query * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Query::finished)) {
                *result = 2;
                return;
            }
        }
    }
}

const QMetaObject KXmlRpc::Query::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KXmlRpc__Query.data,
      qt_meta_data_KXmlRpc__Query,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KXmlRpc::Query::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KXmlRpc::Query::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KXmlRpc__Query.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KXmlRpc::Query::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void KXmlRpc::Query::message(const QList<QVariant> & _t1, const QVariant & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KXmlRpc::Query::fault(int _t1, const QString & _t2, const QVariant & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KXmlRpc::Query::finished(Query * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
