/****************************************************************************
** Meta object code from reading C++ file 'client.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kxmlrpcclient-5.43.0/src/client.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'client.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KXmlRpc__Client_t {
    QByteArrayData data[14];
    char stringdata0[112];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KXmlRpc__Client_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KXmlRpc__Client_t qt_meta_stringdata_KXmlRpc__Client = {
    {
QT_MOC_LITERAL(0, 0, 15), // "KXmlRpc::Client"
QT_MOC_LITERAL(1, 16, 4), // "call"
QT_MOC_LITERAL(2, 21, 0), // ""
QT_MOC_LITERAL(3, 22, 6), // "method"
QT_MOC_LITERAL(4, 29, 4), // "args"
QT_MOC_LITERAL(5, 34, 6), // "msgObj"
QT_MOC_LITERAL(6, 41, 11), // "const char*"
QT_MOC_LITERAL(7, 53, 11), // "messageSlot"
QT_MOC_LITERAL(8, 65, 8), // "faultObj"
QT_MOC_LITERAL(9, 74, 9), // "faultSlot"
QT_MOC_LITERAL(10, 84, 2), // "id"
QT_MOC_LITERAL(11, 87, 3), // "arg"
QT_MOC_LITERAL(12, 91, 13), // "queryFinished"
QT_MOC_LITERAL(13, 105, 6) // "Query*"

    },
    "KXmlRpc::Client\0call\0\0method\0args\0"
    "msgObj\0const char*\0messageSlot\0faultObj\0"
    "faultSlot\0id\0arg\0queryFinished\0Query*"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KXmlRpc__Client[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      19,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    7,  109,    2, 0x0a /* Public */,
       1,    6,  124,    2, 0x2a /* Public | MethodCloned */,
       1,    7,  137,    2, 0x0a /* Public */,
       1,    6,  152,    2, 0x2a /* Public | MethodCloned */,
       1,    7,  165,    2, 0x0a /* Public */,
       1,    6,  180,    2, 0x2a /* Public | MethodCloned */,
       1,    7,  193,    2, 0x0a /* Public */,
       1,    6,  208,    2, 0x2a /* Public | MethodCloned */,
       1,    7,  221,    2, 0x0a /* Public */,
       1,    6,  236,    2, 0x2a /* Public | MethodCloned */,
       1,    7,  249,    2, 0x0a /* Public */,
       1,    6,  264,    2, 0x2a /* Public | MethodCloned */,
       1,    7,  277,    2, 0x0a /* Public */,
       1,    6,  292,    2, 0x2a /* Public | MethodCloned */,
       1,    7,  305,    2, 0x0a /* Public */,
       1,    6,  320,    2, 0x2a /* Public | MethodCloned */,
       1,    7,  333,    2, 0x0a /* Public */,
       1,    6,  348,    2, 0x2a /* Public | MethodCloned */,
      12,    1,  361,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::QString, QMetaType::QVariantList, QMetaType::QObjectStar, 0x80000000 | 6, QMetaType::QObjectStar, 0x80000000 | 6, QMetaType::QVariant,    3,    4,    5,    7,    8,    9,   10,
    QMetaType::Void, QMetaType::QString, QMetaType::QVariantList, QMetaType::QObjectStar, 0x80000000 | 6, QMetaType::QObjectStar, 0x80000000 | 6,    3,    4,    5,    7,    8,    9,
    QMetaType::Void, QMetaType::QString, QMetaType::QVariant, QMetaType::QObjectStar, 0x80000000 | 6, QMetaType::QObjectStar, 0x80000000 | 6, QMetaType::QVariant,    3,   11,    5,    7,    8,    9,   10,
    QMetaType::Void, QMetaType::QString, QMetaType::QVariant, QMetaType::QObjectStar, 0x80000000 | 6, QMetaType::QObjectStar, 0x80000000 | 6,    3,   11,    5,    7,    8,    9,
    QMetaType::Void, QMetaType::QString, QMetaType::Int, QMetaType::QObjectStar, 0x80000000 | 6, QMetaType::QObjectStar, 0x80000000 | 6, QMetaType::QVariant,    3,   11,    5,    7,    8,    9,   10,
    QMetaType::Void, QMetaType::QString, QMetaType::Int, QMetaType::QObjectStar, 0x80000000 | 6, QMetaType::QObjectStar, 0x80000000 | 6,    3,   11,    5,    7,    8,    9,
    QMetaType::Void, QMetaType::QString, QMetaType::Bool, QMetaType::QObjectStar, 0x80000000 | 6, QMetaType::QObjectStar, 0x80000000 | 6, QMetaType::QVariant,    3,   11,    5,    7,    8,    9,   10,
    QMetaType::Void, QMetaType::QString, QMetaType::Bool, QMetaType::QObjectStar, 0x80000000 | 6, QMetaType::QObjectStar, 0x80000000 | 6,    3,   11,    5,    7,    8,    9,
    QMetaType::Void, QMetaType::QString, QMetaType::Double, QMetaType::QObjectStar, 0x80000000 | 6, QMetaType::QObjectStar, 0x80000000 | 6, QMetaType::QVariant,    3,   11,    5,    7,    8,    9,   10,
    QMetaType::Void, QMetaType::QString, QMetaType::Double, QMetaType::QObjectStar, 0x80000000 | 6, QMetaType::QObjectStar, 0x80000000 | 6,    3,   11,    5,    7,    8,    9,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::QObjectStar, 0x80000000 | 6, QMetaType::QObjectStar, 0x80000000 | 6, QMetaType::QVariant,    3,   11,    5,    7,    8,    9,   10,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::QObjectStar, 0x80000000 | 6, QMetaType::QObjectStar, 0x80000000 | 6,    3,   11,    5,    7,    8,    9,
    QMetaType::Void, QMetaType::QString, QMetaType::QByteArray, QMetaType::QObjectStar, 0x80000000 | 6, QMetaType::QObjectStar, 0x80000000 | 6, QMetaType::QVariant,    3,   11,    5,    7,    8,    9,   10,
    QMetaType::Void, QMetaType::QString, QMetaType::QByteArray, QMetaType::QObjectStar, 0x80000000 | 6, QMetaType::QObjectStar, 0x80000000 | 6,    3,   11,    5,    7,    8,    9,
    QMetaType::Void, QMetaType::QString, QMetaType::QDateTime, QMetaType::QObjectStar, 0x80000000 | 6, QMetaType::QObjectStar, 0x80000000 | 6, QMetaType::QVariant,    3,   11,    5,    7,    8,    9,   10,
    QMetaType::Void, QMetaType::QString, QMetaType::QDateTime, QMetaType::QObjectStar, 0x80000000 | 6, QMetaType::QObjectStar, 0x80000000 | 6,    3,   11,    5,    7,    8,    9,
    QMetaType::Void, QMetaType::QString, QMetaType::QStringList, QMetaType::QObjectStar, 0x80000000 | 6, QMetaType::QObjectStar, 0x80000000 | 6, QMetaType::QVariant,    3,   11,    5,    7,    8,    9,   10,
    QMetaType::Void, QMetaType::QString, QMetaType::QStringList, QMetaType::QObjectStar, 0x80000000 | 6, QMetaType::QObjectStar, 0x80000000 | 6,    3,   11,    5,    7,    8,    9,
    QMetaType::Void, 0x80000000 | 13,    2,

       0        // eod
};

void KXmlRpc::Client::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Client *_t = static_cast<Client *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->call((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QList<QVariant>(*)>(_a[2])),(*reinterpret_cast< QObject*(*)>(_a[3])),(*reinterpret_cast< const char*(*)>(_a[4])),(*reinterpret_cast< QObject*(*)>(_a[5])),(*reinterpret_cast< const char*(*)>(_a[6])),(*reinterpret_cast< const QVariant(*)>(_a[7]))); break;
        case 1: _t->call((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QList<QVariant>(*)>(_a[2])),(*reinterpret_cast< QObject*(*)>(_a[3])),(*reinterpret_cast< const char*(*)>(_a[4])),(*reinterpret_cast< QObject*(*)>(_a[5])),(*reinterpret_cast< const char*(*)>(_a[6]))); break;
        case 2: _t->call((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QVariant(*)>(_a[2])),(*reinterpret_cast< QObject*(*)>(_a[3])),(*reinterpret_cast< const char*(*)>(_a[4])),(*reinterpret_cast< QObject*(*)>(_a[5])),(*reinterpret_cast< const char*(*)>(_a[6])),(*reinterpret_cast< const QVariant(*)>(_a[7]))); break;
        case 3: _t->call((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QVariant(*)>(_a[2])),(*reinterpret_cast< QObject*(*)>(_a[3])),(*reinterpret_cast< const char*(*)>(_a[4])),(*reinterpret_cast< QObject*(*)>(_a[5])),(*reinterpret_cast< const char*(*)>(_a[6]))); break;
        case 4: _t->call((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< QObject*(*)>(_a[3])),(*reinterpret_cast< const char*(*)>(_a[4])),(*reinterpret_cast< QObject*(*)>(_a[5])),(*reinterpret_cast< const char*(*)>(_a[6])),(*reinterpret_cast< const QVariant(*)>(_a[7]))); break;
        case 5: _t->call((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< QObject*(*)>(_a[3])),(*reinterpret_cast< const char*(*)>(_a[4])),(*reinterpret_cast< QObject*(*)>(_a[5])),(*reinterpret_cast< const char*(*)>(_a[6]))); break;
        case 6: _t->call((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])),(*reinterpret_cast< QObject*(*)>(_a[3])),(*reinterpret_cast< const char*(*)>(_a[4])),(*reinterpret_cast< QObject*(*)>(_a[5])),(*reinterpret_cast< const char*(*)>(_a[6])),(*reinterpret_cast< const QVariant(*)>(_a[7]))); break;
        case 7: _t->call((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])),(*reinterpret_cast< QObject*(*)>(_a[3])),(*reinterpret_cast< const char*(*)>(_a[4])),(*reinterpret_cast< QObject*(*)>(_a[5])),(*reinterpret_cast< const char*(*)>(_a[6]))); break;
        case 8: _t->call((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< double(*)>(_a[2])),(*reinterpret_cast< QObject*(*)>(_a[3])),(*reinterpret_cast< const char*(*)>(_a[4])),(*reinterpret_cast< QObject*(*)>(_a[5])),(*reinterpret_cast< const char*(*)>(_a[6])),(*reinterpret_cast< const QVariant(*)>(_a[7]))); break;
        case 9: _t->call((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< double(*)>(_a[2])),(*reinterpret_cast< QObject*(*)>(_a[3])),(*reinterpret_cast< const char*(*)>(_a[4])),(*reinterpret_cast< QObject*(*)>(_a[5])),(*reinterpret_cast< const char*(*)>(_a[6]))); break;
        case 10: _t->call((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< QObject*(*)>(_a[3])),(*reinterpret_cast< const char*(*)>(_a[4])),(*reinterpret_cast< QObject*(*)>(_a[5])),(*reinterpret_cast< const char*(*)>(_a[6])),(*reinterpret_cast< const QVariant(*)>(_a[7]))); break;
        case 11: _t->call((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< QObject*(*)>(_a[3])),(*reinterpret_cast< const char*(*)>(_a[4])),(*reinterpret_cast< QObject*(*)>(_a[5])),(*reinterpret_cast< const char*(*)>(_a[6]))); break;
        case 12: _t->call((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QByteArray(*)>(_a[2])),(*reinterpret_cast< QObject*(*)>(_a[3])),(*reinterpret_cast< const char*(*)>(_a[4])),(*reinterpret_cast< QObject*(*)>(_a[5])),(*reinterpret_cast< const char*(*)>(_a[6])),(*reinterpret_cast< const QVariant(*)>(_a[7]))); break;
        case 13: _t->call((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QByteArray(*)>(_a[2])),(*reinterpret_cast< QObject*(*)>(_a[3])),(*reinterpret_cast< const char*(*)>(_a[4])),(*reinterpret_cast< QObject*(*)>(_a[5])),(*reinterpret_cast< const char*(*)>(_a[6]))); break;
        case 14: _t->call((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QDateTime(*)>(_a[2])),(*reinterpret_cast< QObject*(*)>(_a[3])),(*reinterpret_cast< const char*(*)>(_a[4])),(*reinterpret_cast< QObject*(*)>(_a[5])),(*reinterpret_cast< const char*(*)>(_a[6])),(*reinterpret_cast< const QVariant(*)>(_a[7]))); break;
        case 15: _t->call((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QDateTime(*)>(_a[2])),(*reinterpret_cast< QObject*(*)>(_a[3])),(*reinterpret_cast< const char*(*)>(_a[4])),(*reinterpret_cast< QObject*(*)>(_a[5])),(*reinterpret_cast< const char*(*)>(_a[6]))); break;
        case 16: _t->call((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2])),(*reinterpret_cast< QObject*(*)>(_a[3])),(*reinterpret_cast< const char*(*)>(_a[4])),(*reinterpret_cast< QObject*(*)>(_a[5])),(*reinterpret_cast< const char*(*)>(_a[6])),(*reinterpret_cast< const QVariant(*)>(_a[7]))); break;
        case 17: _t->call((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2])),(*reinterpret_cast< QObject*(*)>(_a[3])),(*reinterpret_cast< const char*(*)>(_a[4])),(*reinterpret_cast< QObject*(*)>(_a[5])),(*reinterpret_cast< const char*(*)>(_a[6]))); break;
        case 18: _t->d->queryFinished((*reinterpret_cast< Query*(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject KXmlRpc::Client::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KXmlRpc__Client.data,
      qt_meta_data_KXmlRpc__Client,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KXmlRpc::Client::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KXmlRpc::Client::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KXmlRpc__Client.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KXmlRpc::Client::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 19;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
